require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_diskaccesspath',
  dscmeta_resource_friendly_name: 'DiskAccessPath',
  dscmeta_resource_name: 'DSC_DiskAccessPath',
  dscmeta_module_name: 'StorageDsc',
  dscmeta_module_version: '5.0.1',
  docs: %q{
    The DSC DiskAccessPath resource type.
    Automatically generated from version 5.0.1
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_nodefaultdriveletter: {
      type: "Optional[Boolean]",
      desc: %q{
        Specifies no automatic drive letter assignment to the partition: Defaults to True
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_fsformat: {
      type: "Optional[Enum['NTFS', 'ReFS']]",
      desc: %q{
        Specifies the file system format of the new volume.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_diskidtype: {
      type: "Optional[Enum['Number', 'UniqueId', 'Guid', 'Location']]",
      desc: %q{
        Specifies the identifier type the DiskId contains. Defaults to Number.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_accesspath: {
      type: "String",
      desc: %q{
        Specifies the access path folder to the assign the disk volume to.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allocationunitsize: {
      type: "Optional[Integer[0, 4294967295]]",
      desc: %q{
        Specifies the allocation unit size to use when formatting the volume.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_size: {
      type: "Optional[Integer[0, 18446744073709551615]]",
      desc: %q{
        Specifies the size of new volume.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_fslabel: {
      type: "Optional[String]",
      desc: %q{
        Define volume label if required.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_diskid: {
      type: "String",
      desc: %q{
        Specifies the disk identifier for the disk to modify.
      },

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
